@@ -4,7 +4,7 @@ mod traits;
 use super::*;
 
 /// A color with red, green, blue, and alpha components.
-#[derive(Debug, Copy, Clone, PartialEq)]
+#[derive(Debug, Copy, Clone)]
 pub struct RGBA(Srgba);
 
 impl RGBA {
