@@ -6,7 +6,9 @@ use std::{
 mod color;
 mod lines;
 mod points;
+mod shape;
 
 pub use color::RGBA;
-pub use lines::{LineColor, LineWidth};
-pub use points::{PointColor, PointSize};
+pub use lines::{LineColor, LineStyle, LineWidth};
+pub use points::{PointColor, PointSize, PointStyle};
+pub use shape::StyledShape;
